//+------------------------------------------------------------------+
//|                                           Auto-Profit-Closer.mq4 |
//|                             Copyright 2024, Trade Smart FX Tools |
//|                                 https://tradesmartfxtools.online |
//+------------------------------------------------------------------+
#property copyright "Copyright 2024, Trade Smart FX Tools"
#property link      " https://tradesmartfxtools.online"
#property version   "1.00"
#property strict

string labelName = "tradesmartfxtools.online";
string labelText = "EA by tradesmartfxtools.online";
int labelFontSize = 18;
color labelColor = Yellow;
int spaceFromBottom = 50;

void createOrUpdateLabel()
  {
// Check if the label already exists
   if(ObjectCreate(0, labelName, OBJ_LABEL, 0, 0, 0))
     {
      // Set label properties
    ObjectSetInteger(0, labelName, OBJPROP_COLOR, StringToInteger(labelText));
// Clear default text
      ObjectSetInteger(0, labelName, OBJPROP_CORNER, CORNER_LEFT_LOWER);  // Set the left-bottom corner
      ObjectSetInteger(0, labelName, OBJPROP_XDISTANCE, 10);  // Distance from the left edge
      ObjectSetInteger(0, labelName, OBJPROP_YDISTANCE, spaceFromBottom);  // Distance from the bottom edge
      ObjectSetInteger(0, labelName, OBJPROP_COLOR, labelColor);
      ObjectSetInteger(0, labelName, OBJPROP_FONTSIZE, labelFontSize);
      ObjectSetInteger(0, labelName, OBJPROP_SELECTABLE, false);
      ObjectSetInteger(0, labelName, OBJPROP_SELECTED, false);
      ObjectSetString(0, labelName, OBJPROP_TEXT, labelText);  // Set label text
     }
   
  }


// Define a global variable for the target profit
input double TargetProfit = 0.2;  


//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
{
 createOrUpdateLabel(); 
    return(INIT_SUCCEEDED);
}

// Function to calculate the total profit of all open deals
double CalculateTotalProfit() {
    double totalProfit = 0;
    int totalOrders = OrdersTotal(); // Get the total number of open orders

    // Loop through all open orders
    for (int i = 0; i < totalOrders; i++) {
        if (OrderSelect(i, SELECT_BY_POS, MODE_TRADES)) { // Select order by position
            totalProfit += OrderProfit();  // Sum up the profit of each open order
        }
    }
    return totalProfit;
}

// Function to close all open orders
void CloseAllOrders() {
    int totalOrders = OrdersTotal(); // Get the total number of open orders

    // Loop through all open orders
    for (int i = totalOrders - 1; i >= 0; i--) { // Iterate from last to first order to safely close
        if (OrderSelect(i, SELECT_BY_POS, MODE_TRADES)) {  // Select the order by position
            int orderType = OrderType();  // Get the type of order (buy/sell)

            // Close BUY order
            if (orderType == OP_BUY) {
                OrderClose(OrderTicket(), OrderLots(), Bid, 3, clrNONE);
            }
            // Close SELL order
            if (orderType == OP_SELL) {
                OrderClose(OrderTicket(), OrderLots(), Ask, 3, clrNONE);
            }
        }
    }
}

// Function to check the total profit and close all trades if the target profit is reached
void CheckAndCloseDeals() {
    double totalProfit = CalculateTotalProfit();  // Get the total profit

    // If total profit exceeds or equals the target, close all deals
    if (totalProfit >= TargetProfit) {
        CloseAllOrders();  // Close all open orders
    }
}

// The main OnTick function that is called on every price update
void OnTick() {
    // Call the function to check and close deals if the profit threshold is reached
    CheckAndCloseDeals();
}

